# WebDownloader

WebDownloader is a Python package using Selenium to download web content. It is easy to use. Just start with this command:

    > python create_db.py

Then run the script:

    > python process_url.py

It will create a database with the crawled and parsed data from the web. Feel free to change it and play around with it.

Thanks a lot for your time and God bless you.



> Written with [StackEdit](https://stackedit.io/).
